@@ -9,7 +9,11 @@ FEMTOLITERS_PER_CELL = "fL/cell"
 GRAMS_PER_DECILITER = "g/dL"
 GRAMS_PER_LITER = "g/L"
 IU_LITER = "IU/L"
-IU_LITER_DISPLAY = mark_safe("U/L")
+IU_LITER_DISPLAY = mark_safe("IU/L")
+MILLI_IU_LITER = "mIU/L"
+MILLI_IU_LITER_DISPLAY = mark_safe("mIU/L")
+MICRO_IU_MILLILITER = "uIU/mL"
+MICRO_IU_MILLILITER_DISPLAY = mark_safe("μIU/mL")
 MICROMOLES_PER_LITER = "umol/L"
 MICROMOLES_PER_LITER_DISPLAY = "μmol/L (micromoles/L)"
 MILLIGRAMS_PER_DECILITER = "mg/dL"
